@@ -25,7 +25,8 @@
 #define __CAPPLET_UTIL_H
 
 #include <gio/gio.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <gconf/gconf.h>
 #include <gconf/gconf-changeset.h>
 
@@ -35,18 +36,11 @@
 
 #define WID(s) glade_xml_get_widget (dialog, s)
 
-/* Copy a setting from the legacy gnome-config settings to the ConfigDatabase */
-
-#define COPY_FROM_LEGACY(type, key, legacy_key)                                 \
-	val_##type = gnome_config_get_##type##_with_default (legacy_key, &def); \
-                                                                                \
-	if (!def)                                                               \
-		gconf_client_set_##type (client, key, val_##type, NULL);
-
 /* Some miscellaneous functions useful to all capplets */
 
-void capplet_help (GtkWindow *parent, char const *helpfile, char const *section);
+void capplet_help (GtkWindow *parent, char const *section);
 void capplet_set_icon (GtkWidget *window, char const *icon_file_name);
 gboolean capplet_file_delete_recursive (GFile *directory, GError **error);
+void capplet_init (GOptionContext *context, int *argc, char ***argv);
 
 #endif /* __CAPPLET_UTIL_H */
