@@ -395,7 +395,7 @@ clear_old_model (GladeXML *dialog)
 
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (WID ("actions_swindow")),
 				  GTK_POLICY_NEVER, GTK_POLICY_NEVER);
-  gtk_widget_set_usize (WID ("actions_swindow"), -1, -1);
+  gtk_widget_set_size_request (WID ("actions_swindow"), -1, -1);
 }
 
 typedef struct {
@@ -611,7 +611,6 @@ append_keys_to_tree (GladeXML           *dialog,
 	  /* Only print a warning for keys that should have a schema */
 	  if (keys_list[j].description_name == NULL)
 	    g_warning ("No description for key '%s'", key_string);
-	  description = g_path_get_basename (key_string);
 	}
 
       if (keys_list[j].cmd_name != NULL)
@@ -1468,7 +1467,11 @@ update_custom_shortcut (GtkTreeModel *model, GtkTreeIter *iter)
       gtk_tree_store_set (GTK_TREE_STORE (model), iter,
 			  KEYENTRY_COLUMN, key, -1);
       client = gconf_client_get_default ();
-      gconf_client_set_string (client, key->desc_gconf_key, key->description, NULL);
+      if (key->description != NULL)
+        gconf_client_set_string (client, key->desc_gconf_key, key->description, NULL);
+      else
+        gconf_client_unset (client, key->desc_gconf_key, NULL);
+      gconf_client_set_string (client, key->cmd_gconf_key, key->command, NULL);
       g_object_unref (client);
     }
 }
