@@ -25,8 +25,8 @@
 
 #include <config.h>
 
+#include <glib/gi18n.h>
 #include <string.h>
-#include <gnome.h>
 #include <gconf/gconf-client.h>
 #include <glade/glade.h>
 #include <gdk/gdkx.h>
@@ -235,23 +235,23 @@ event_box_button_press_event (GtkWidget   *widget,
 		double_click_time = gconf_value_get_int (value);
 
 	if (test_maybe_timeout_id != 0)
-		gtk_timeout_remove  (test_maybe_timeout_id);
+		g_source_remove  (test_maybe_timeout_id);
 	if (test_on_timeout_id != 0)
-		gtk_timeout_remove (test_on_timeout_id);
+		g_source_remove (test_on_timeout_id);
 
 	switch (double_click_state) {
 	case DOUBLE_CLICK_TEST_OFF:
 		double_click_state = DOUBLE_CLICK_TEST_MAYBE;
 		data.image = image;
 		data.timeout_id = &test_maybe_timeout_id;
-		test_maybe_timeout_id = gtk_timeout_add (double_click_time, (GtkFunction) test_maybe_timeout, &data);
+		test_maybe_timeout_id = g_timeout_add (double_click_time, (GtkFunction) test_maybe_timeout, &data);
 		break;
 	case DOUBLE_CLICK_TEST_MAYBE:
 		if (event->time - double_click_timestamp < double_click_time) {
 			double_click_state = DOUBLE_CLICK_TEST_ON;
 			data.image = image;
 			data.timeout_id = &test_on_timeout_id;
-			test_on_timeout_id = gtk_timeout_add (2500, (GtkFunction) test_maybe_timeout, &data);
+			test_on_timeout_id = g_timeout_add (2500, (GtkFunction) test_maybe_timeout, &data);
 		}
 		break;
 	case DOUBLE_CLICK_TEST_ON:
@@ -419,7 +419,6 @@ dialog_response_cb (GtkDialog *dialog, gint response_id, GConfChangeSet *changes
 {
 	if (response_id == GTK_RESPONSE_HELP)
 		capplet_help (GTK_WINDOW (dialog),
-			      "user-guide.xml",
 			      "goscustperiph-5");
 	else
 		gtk_main_quit ();
@@ -428,13 +427,12 @@ dialog_response_cb (GtkDialog *dialog, gint response_id, GConfChangeSet *changes
 int
 main (int argc, char **argv)
 {
-	GnomeProgram   *program;
 	GConfClient    *client;
 	GladeXML       *dialog;
 	GtkWidget      *dialog_win, *w;
-	GOptionContext *context;
 	gchar *start_page = NULL;
 
+	GOptionContext *context;
 	GOptionEntry cap_options[] = {
 		{"show-page", 'p', G_OPTION_FLAG_IN_MAIN,
 		 G_OPTION_ARG_STRING,
@@ -445,20 +443,10 @@ main (int argc, char **argv)
 		{NULL}
 	};
 
-	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
 	context = g_option_context_new (_("- GNOME Mouse Preferences"));
-	g_option_context_add_main_entries (context, cap_options,
-					   GETTEXT_PACKAGE);
-
-	program = gnome_program_init ("gnome-mouse-properties", VERSION,
-				      LIBGNOMEUI_MODULE, argc, argv,
-				      GNOME_PARAM_GOPTION_CONTEXT, context,
-				      GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
-				      NULL);
-
+	g_option_context_add_main_entries (context, cap_options, GETTEXT_PACKAGE);
+	capplet_init (context, &argc, &argv);
+	
 	capplet_init_stock_icons ();
 
 	activate_settings_daemon ();
@@ -504,7 +492,6 @@ main (int argc, char **argv)
 	}
 
 	g_object_unref (client);
-	g_object_unref (program);
 
 	return 0;
 }
